@@ -49,9 +49,11 @@ Examples:
     {example output}
     ...
 """
-from typing import Dict, Iterable
+from typing import Dict, Iterable, Union
 import jc.utils
-from jc.utils import stream_success, stream_error
+from jc.streaming import (
+    add_jc_meta, streaming_input_type_check, streaming_line_input_type_check, raise_or_yield
+)
 from jc.exceptions import ParseError
 
 
@@ -63,7 +65,7 @@ class info():
     author_email = 'johndoe@gmail.com'
 
     # compatible options: linux, darwin, cygwin, win32, aix, freebsd
-    compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
+    compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
     streaming = True
 
 
@@ -91,12 +93,13 @@ def _process(proc_data: Dict) -> Dict:
     return proc_data
 
 
+@add_jc_meta
 def parse(
     data: Iterable[str],
     raw: bool = False,
     quiet: bool = False,
     ignore_exceptions: bool = False
-) -> Iterable[Dict]:
+) -> Union[Iterable[Dict], tuple]:
     """
     Main text parsing generator function. Returns an iterator object.
 
@@ -115,24 +118,24 @@ def parse(
 
     Returns:
 
-        Iterator object
+        Iterator object (generator)
     """
     jc.utils.compatibility(__name__, info.compatible, quiet)
-    jc.utils.streaming_input_type_check(data)
+    streaming_input_type_check(data)
 
     for line in data:
-        output_line: Dict = {}
         try:
-            jc.utils.streaming_line_input_type_check(line)
+            streaming_line_input_type_check(line)
+            output_line: Dict = {}
 
             # parse the content here
             # check out helper functions in jc.utils
             # and jc.parsers.universal
 
             if output_line:
-                yield stream_success(output_line, ignore_exceptions) if raw else stream_success(_process(output_line), ignore_exceptions)
+                yield output_line if raw else _process(output_line)
             else:
                 raise ParseError('Not foo data')
 
         except Exception as e:
-            yield stream_error(e, ignore_exceptions, line)
+            yield raise_or_yield(ignore_exceptions, e, line)
