@@ -1,4 +1,5 @@
-"""jc - JSON CLI output utility `systemctl list-sockets` command output parser
+"""jc - JSON CLI output utility `systemctl list-sockets` command output
+parser
 
 Usage (cli):
 
@@ -10,6 +11,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('systemctl_ls', systemctl_ls_command_output)
+
+    or
+
     import jc.parsers.systemctl_ls
     result = jc.parsers.systemctl_ls.parse(systemctl_ls_command_output)
 
@@ -54,8 +60,6 @@ class info():
     description = '`systemctl list-sockets` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux']
     magic_commands = ['systemctl list-sockets']
 
@@ -86,7 +90,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
